.TH mpsyslin  1 " " " " "Maxplus Function"
.SH NAME
mpsyslin - maxplus linear system constructor
.SH CALLING SEQUENCE
.nf
[sl]=syslin(A,B,C [,D [,x0] ])
.fi
.SH PARAMETERS
.TP 10
A,B,C,D
: matrices of the state-space representation (\fVD\fR optional
with maxplus zero matrix as default value). 
.TP 10
x0
: vector (initial state; default value is \fV-inf\fR)
.TP 10
sl
: tlist ("\fVmpls\fR" list) representing the linear system
.SH DESCRIPTION
mpsyslin  defines an  implicit dynamic linear maxplus system as a list
and checks the consistency of data in the state space representation.
.LP
.nf
sl=mpsyslin(A,B,C [,D [,x0] ])
.fi
represents the maxplus system :
.nf
      x(n) =  D*x(n) + A*x(n-1) + B*u(n)
        y  =  C*x(n) 
      x(0) = x0
.fi
The output of \fVmplsyslin\fR is a list of the following form: 
sl=tlist(['mpls','A','B','C','D','X0'],A,B,C,D,x0)
printed 
.nf
      x=Dx+Ax'+Bu
      y=Cx
.fi
as soon as the sizes of the matrices are compatible with this pretty print.
.LP
Maxplus Linear systems defined as \fVmpsyslin\fR can be manipulated as
usual matrices -- see examples below.
.LP
Most of maxplus state-space control functions receive a \fVmpsyslin\fR list as input instead
of the four matrices defining the system.
.SH EXAMPLES
.nf
A=[%0,1;%0,%0];B=#([1;1]);C=#([1,1]);
S1=mpsyslin(A,B,C) 
S1("A")
S1("D")
S1("X0")
S2=mpsyslin([%1],[%1],[%1])
S1+S2 // Parallel composition
S2*S1 // Series composition
[S1,S2] // Output addition composition
[S1;S2] // Input in common composition
S3=S1|S2 // Diagonal composition
S1/.S2 // star(S1*S2)*S1 Feedback composition
S3(1,1) // Subsystem  extraction
.fi
.SH SEE ALSO
tlist
